==> haskell-http-client-0.4.27-3-armv7h.pkg.tar.xz: usr/share/haskell/haskell-http-client/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: http-client
version: 0.4.27
id: http-client-0.4.27-649349307b7fbc2da7ba4e3fdfb27d3d
key: httpc_BK8pBIZK5eBJ6SslCRgQ3D
license: MIT
maintainer: michael@snoyman.com
homepage: https://github.com/snoyberg/http-client
synopsis: An HTTP client engine, intended as a base layer for more user-friendly packages.
description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/http-client>.
category: Network
author: Michael Snoyman
exposed: True
exposed-modules:
    Network.HTTP.Client Network.HTTP.Client.MultipartFormData
    Network.HTTP.Client.Internal
hidden-modules: Network.HTTP.Client.Body
                Network.HTTP.Client.Connection Network.HTTP.Client.Cookies
                Network.HTTP.Client.Core Network.HTTP.Client.Headers
                Network.HTTP.Client.Manager Network.HTTP.Client.Request
                Network.HTTP.Client.Response Network.HTTP.Client.Types
                Network.HTTP.Client.Util Network.PublicSuffixList.Lookup
                Network.PublicSuffixList.Types Network.PublicSuffixList.Serialize
                Network.PublicSuffixList.DataStructure
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/http-client-0.4.27
library-dirs: /usr/lib/ghc-7.10.3/site-local/http-client-0.4.27
data-dir: /usr/share/arm-linux-ghc-7.10.3/http-client-0.4.27
hs-libraries: HShttp-client-0.4.27-BK8pBIZK5eBJ6SslCRgQ3D
depends:
    array-0.5.1.0-a4b4f31b03b7779670557ea46745a386
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    base64-bytestring-1.0.0.1-7819850819049320f81b6417431cc8a5
    blaze-builder-0.4.0.1-3daa45cd3be9618b289586d273c59e36
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    case-insensitive-1.2.0.5-6669cd7a393ccedc4f66c0a01b6f0e2f
    containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
    cookie-0.4.1.6-8a746b417cee9e54ae77a0b2d5e8515e
    data-default-class-0.0.1-fcbab95490d730dd2489b628499587cd
    deepseq-1.4.1.1-3975618f889b45239daa47b7443eaeee
    exceptions-0.8.2.1-8c1fe53cd5846ab1f6d4c58870c4f8d9
    filepath-1.4.0.0-73e0bec80594160bf6dd6cb25217c6bf
    ghc-prim-0.4.0.0-bf246eb9fdda7435f0c147a313ce59fb
    http-types-0.9-d392878af9c5e1b1993961dc71a9e177
    mime-types-0.1.0.6-1ae582cd69235deb20f7c2577dd8b3dc
    network-2.6.2.1-602ee4a12c5a174f6683a75303a065d3
    network-uri-2.6.0.3-27316eb865f3b3562ae77903534d67a4
    random-1.1-41a0a7ecd483c665a5c3a093a5be2968
    streaming-commons-0.1.15.2-092d722155f2dc7f0b2e7a0dc037f30c
    text-1.2.2.0-2f82ea4adfdd656d9a8840ad2ee17cc0
    time-1.5.0.1-cf94b0d806e26f6c4e356671290061b2
    transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
haddock-interfaces: /usr/share/doc/haskell-http-client/html/http-client.haddock
haddock-html: /usr/share/doc/haskell-http-client/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"

==> haskell-http-client-0.4.27-6-armv7h.pkg.tar.xz: usr/share/haskell/haskell-http-client/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: http-client
version: 0.4.27
id: http-client-0.4.27-1cd31210c8ec4a6e0b4cc467bd24f592
key: httpc_2ftXothlM7QEUjpCnKv1nA
license: MIT
maintainer: michael@snoyman.com
homepage: https://github.com/snoyberg/http-client
synopsis: An HTTP client engine, intended as a base layer for more user-friendly packages.
description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/http-client>.
category: Network
author: Michael Snoyman
exposed: True
exposed-modules:
    Network.HTTP.Client Network.HTTP.Client.MultipartFormData
    Network.HTTP.Client.Internal
hidden-modules: Network.HTTP.Client.Body
                Network.HTTP.Client.Connection Network.HTTP.Client.Cookies
                Network.HTTP.Client.Core Network.HTTP.Client.Headers
                Network.HTTP.Client.Manager Network.HTTP.Client.Request
                Network.HTTP.Client.Response Network.HTTP.Client.Types
                Network.HTTP.Client.Util Network.PublicSuffixList.Lookup
                Network.PublicSuffixList.Types Network.PublicSuffixList.Serialize
                Network.PublicSuffixList.DataStructure
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/http-client-0.4.27
library-dirs: /usr/lib/ghc-7.10.3/site-local/http-client-0.4.27
data-dir: /usr/share/arm-linux-ghc-7.10.3/http-client-0.4.27
hs-libraries: HShttp-client-0.4.27-2ftXothlM7QEUjpCnKv1nA
depends:
    array-0.5.1.0-a4b4f31b03b7779670557ea46745a386
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    base64-bytestring-1.0.0.1-7819850819049320f81b6417431cc8a5
    blaze-builder-0.4.0.1-0c3e4ae1ea19a65d81d24f4a911c903b
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    case-insensitive-1.2.0.6-c6baeb35be7a5ef7e8151f5e00d87f59
    containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
    cookie-0.4.1.6-97fa5cf54d4ed1e2644dbcebe7255b51
    data-default-class-0.0.1-fcbab95490d730dd2489b628499587cd
    deepseq-1.4.1.1-3975618f889b45239daa47b7443eaeee
    exceptions-0.8.2.1-8c1fe53cd5846ab1f6d4c58870c4f8d9
    filepath-1.4.0.0-73e0bec80594160bf6dd6cb25217c6bf
    ghc-prim-0.4.0.0-bf246eb9fdda7435f0c147a313ce59fb
    http-types-0.9-a274b17bf4f057225e6c0af6d57f03ec
    mime-types-0.1.0.6-7d5f22022675c00ea07fd0f1df020c2e
    network-2.6.2.1-602ee4a12c5a174f6683a75303a065d3
    network-uri-2.6.1.0-0e39aca8530572505c01ef548c540bd6
    random-1.1-41a0a7ecd483c665a5c3a093a5be2968
    streaming-commons-0.1.15.2-e8e35f9b3c5e3a1a9d565bf7c4ec1900
    text-1.2.2.1-18afbfeccf88d72c4b6e468c86d2b77d
    time-1.5.0.1-cf94b0d806e26f6c4e356671290061b2
    transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
haddock-interfaces: /usr/share/doc/haskell-http-client/html/http-client.haddock
haddock-html: /usr/share/doc/haskell-http-client/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
